@@ -431,9 +431,17 @@ class SortedSet(Container):
         """Returns the members of the set."""
         return self.zrange(0, -1)
 
+    @property
+    def revmembers(self):
+        """Returns the members of the set in reverse."""
+        return self.zrevrange(0, -1)
+
     def __iter__(self):
         return self.members.__iter__()
 
+    def __reversed__(self):
+        return self.revmembers.__iter__()
+
     def __repr__(self):
         return "<%s '%s' %s>" % (self.__class__.__name__, self.key,
                 self.members)
@@ -498,7 +506,7 @@ class SortedSet(Container):
         return self.zrangebyscore(value, value)
 
     DELEGATEABLE_METHODS = ('zadd', 'zrem', 'zincrby', 'zrank',
-            'zrevrank', 'zrange', 'zrangebyscore', 'zcard',
+            'zrevrank', 'zrange', 'zrevrange', 'zrangebyscore', 'zcard',
             'zscore', 'zremrangebyrank', 'zremrangebyscore')
 
 
